<?php
/**
 * @file Do Admin settings
 */

/**
 * Admin settings form
 */
function do_settings() {
  drupal_add_js(drupal_get_path('module', 'do') . '/js/do.admin.js');

  $form = array();

  $form['do_shortcut'] = array(
    '#type' => 'fieldset',
    '#title' => t('Keyboard shortcut'),
    '#description' => t('Select a keyboard modifier and trigger to launch Do. The default is Ctrl + Space.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );

  $form['do_shortcut']['do_modifier'] = array(
    '#type' => 'radios',
    '#name' => 'do_modifier',
    '#title' => t('Do Keyboard Modifier'),
    '#description' => t('Hold the modifier key to start the shortcut'),
    '#required' => TRUE,
    '#default_value' => variable_get('do_modifier', 'ctrl'),
    '#options' => array('ctrl' => 'ctrl', 'shift' => 'shift', 'alt' => 'alt', 'meta' => 'meta'),
  );

  $form['do_shortcut']['do_trigger'] = array(
    '#type' => 'textfield',
    '#name' => 'do_trigger',
    '#title' => t('Do Keyboard Trigger'),
    '#description' => t('Press the trigger key while holding the modifier key to activate Do.'),
    '#required' => TRUE,
    '#default_value' => variable_get('do_trigger', '32'),
    '#maxlength' => 20,
  );

  $form['do_drush'] = array(
    '#type' => 'fieldset',
    '#title' => t('Drush'),
    '#description' => t('Configure Drush settings.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );
  
  $form['do_drush']['do_drush_php'] = array(
    '#type' => 'textfield',
    '#title' => t('PHP Path'),
    '#description' => t('The absolute path to PHP.'),
    '#default_value' => variable_get('do_drush_php', 'php'),
    '#required' => TRUE,
  );
  $form['do_drush']['do_drush_drush'] = array(
    '#type' => 'textfield',
    '#title' => t('Drush Path'),
    '#description' => t('The absolute path to <em>drush.php</em>.'),
    '#default_value' => variable_get('do_drush_drush', ''),
    '#required' => TRUE,
  );
  $form['do_drush']['do_drush_root'] = array(
    '#type' => 'textfield',
    '#title' => t('Drupal Path'),
    '#description' => t('The absolute path to the Drupal installation to use Drush on.'),
    '#default_value' => variable_get('do_drush_root', dirname(realpath('index.php'))),
    '#required' => TRUE,
  );

  $form['do_history'] = array(
    '#type' => 'fieldset',
    '#title' => t('History'),
    '#description' => t('Configure settings related to the history of executed commands.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );

  $form['do_history']['do_history_enable'] = array(
    '#type' => 'checkbox',
    '#name' => 'do_history_enable',
    '#title' => t('Enable history of executed commands'),
    '#default_value' => variable_get('do_history_enable', TRUE)
  );
  
  $form['do_history']['do_history_limit'] = array(
    '#type' => 'select',
    '#name' => 'do_history_limit',
    '#title' => t('Discard log entries above the following row limit'),
    '#options' => drupal_map_assoc(array(100, 1000, 10000, 100000, 1000000)),
    '#description' => t('The maximum number of rows to keep in the database log. Older entries will be automatically discarded. (Requires a correctly configured <a href="@cron">cron maintenance task</a>.)', array('@cron' => url('admin/reports/status'))),
    '#default_value' => variable_get('do_history_limit', 1000)
  );

  return system_settings_form($form);
}
