<?php
/**
 * @file Default Do hooks
 */

/**
 * Clear all caches
 * The simplest hook in the book
 */
function do_flush() {
  cache_clear_all();
  return array('ok' => TRUE, 'msg' => t('Caches cleared'));
}

/**
 * Set an alias
 *
 * @param string $alias
 * @param string $op
 */
function do_alias($alias, $op) {
  $ok = do_set_alias($op, $alias);
  do_cache_rebuild();
  $msg = $ok ? t('Alias created successfully!') : t('Error creating alias');
  return array('ok' => $ok, 'msg' => $msg);
}

/**
 * Forwards commands to Drush
 *
 * @param string|array $params
 */
function do_drush($params) {
  $args = implode('/', (array) $params);
  $php = variable_get('do_drush_php', NULL);
  $drush = variable_get('do_drush_drush', NULL);
  $root = variable_get('do_drush_root', NULL);
  global $base_url;

  if (!isset($php, $drush, $root)) {
    return array('ok' => FALSE, 'msg' => t('You must visit admin/settings/do and configure Drush integration.'));
  }

  $output = array();
  exec("$php $drush -r '$root' -l $base_url" . $args, $output);
  $output = implode(' ', $output);
  // @TODO deal with output prompts
  return array('ok' => TRUE, 'msg' => $output);
}

/**
 * Try to go to a destination
 * Based on drupal_goto
 *
 * @param string|array $destination
 */
function do_goto($destination) {
  $path = implode('/', (array) $destination);
  
  // @TODO check for valid paths?

  // Allow modules to react to the end of the page request before redirecting.
  // We do not want this while running update.php.
  if (!defined('MAINTENANCE_MODE') || MAINTENANCE_MODE != 'update') {
    module_invoke_all('exit', $url);
  }
  
  // Even though session_write_close() is registered as a shutdown function, we
  // need all session data written to the database before redirecting.
  session_write_close();
  
  return array('ok' => TRUE, 'redirect' => $path);
}
